# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_whois_reverse_response_whois_domains_historical_item_domain_registrar import (
    GetWhoisReverseResponseWhoisDomainsHistoricalItemDomainRegistrar,
)


class GetWhoisReverseResponseWhoisDomainsHistoricalItem(UniversalBaseModel):
    num: typing.Optional[int] = None
    status: typing.Optional[bool] = None
    domain_name: typing.Optional[str] = None
    create_date: typing.Optional[str] = None
    update_date: typing.Optional[str] = None
    expiry_date: typing.Optional[str] = None
    domain_registrar: typing.Optional[GetWhoisReverseResponseWhoisDomainsHistoricalItemDomainRegistrar] = None
    name_servers: typing.Optional[typing.List[str]] = None
    domain_status: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
