# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .get_whois_historical_response_whois_domains_historical_item import (
    GetWhoisHistoricalResponseWhoisDomainsHistoricalItem,
)


class GetWhoisHistoricalResponse(UniversalBaseModel):
    status: typing.Optional[bool] = None
    whois: typing.Optional[str] = None
    total_records: typing.Optional[str] = None
    whois_domains_historical: typing.Optional[typing.List[GetWhoisHistoricalResponseWhoisDomainsHistoricalItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
