# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .post_bulkwhois_response_bulk_whois_response_item_domain_registrar import (
    PostBulkwhoisResponseBulkWhoisResponseItemDomainRegistrar,
)
from .post_bulkwhois_response_bulk_whois_response_item_registrant_contact import (
    PostBulkwhoisResponseBulkWhoisResponseItemRegistrantContact,
)


class PostBulkwhoisResponseBulkWhoisResponseItem(UniversalBaseModel):
    status: typing.Optional[bool] = None
    domain_name: typing.Optional[str] = None
    query_time: typing.Optional[str] = None
    whois_server: typing.Optional[str] = None
    domain_registered: typing.Optional[str] = None
    create_date: typing.Optional[dt.datetime] = None
    update_date: typing.Optional[dt.datetime] = None
    expiry_date: typing.Optional[dt.datetime] = None
    domain_registrar: typing.Optional[PostBulkwhoisResponseBulkWhoisResponseItemDomainRegistrar] = None
    registrant_contact: typing.Optional[PostBulkwhoisResponseBulkWhoisResponseItemRegistrantContact] = None
    name_servers: typing.Optional[typing.List[str]] = None
    domain_status: typing.Optional[typing.List[str]] = None
    whois_raw_domain: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
